@@ -135,16 +135,10 @@ class System(base.ResourceBase):
     """Indicates if a given resource has a maintenance window assignment
     for applying settings or operations"""
 
-    _settings = settings.SettingsField()
-    """Settings Resource is used to represent the future intended state
-    of a Resource
-    Ref: http://redfish.dmtf.org/schemas/DSP0266_1.7.0.html#settings-resource
-    """
-
     _actions = ActionsField('Actions', required=True)
 
     def __init__(self, connector, identity, redfish_version=None,
-                 registries=None):
+                 registries=None, root=None):
         """A class representing a ComputerSystem
 
         :param connector: A Connector instance
@@ -153,9 +147,13 @@ class System(base.ResourceBase):
             the object according to schema of the given version.
         :param registries: Dict of registries to be used in any resource
             that needs registries to parse messages.
+        :param root: Sushy root object. Empty for Sushy root itself.
         """
         super(System, self).__init__(
-            connector, identity, redfish_version, registries)
+            connector, identity,
+            redfish_version=redfish_version,
+            registries=registries,
+            root=root)
 
     def _get_reset_action_element(self):
         reset_action = self._actions.reset
@@ -241,26 +239,6 @@ class System(base.ResourceBase):
                     valid_values=valid_targets)
 
             fishy_target = sys_maps.BOOT_SOURCE_TARGET_MAP_REV[target]
-            # NOTE(janders) on SuperMicro X11 and X12 machines, virtual media
-            # is presented as an "USB CD" drive as opposed to a CD drive. Both
-            # are present in the list of boot devices, however only selecting
-            # UsbCd as the boot source results in a successful boot from
-            # vMedia. If "CD" is selected, boot fails even if vMedia is
-            # inserted. This code detects a case where a SuperMicro machine is
-            # about to attempt boot from CD and overrides the boot device to
-            # UsbCd instead which makes boot from vMedia work as expected.
-            if (self.manufacturer and self.manufacturer.lower() == 'supermicro'
-                    and fishy_target == sys_maps.BOOT_SOURCE_TARGET_MAP_REV[
-                        sys_cons.BOOT_SOURCE_TARGET_CD]
-                    and sys_maps.BOOT_SOURCE_TARGET_MAP_REV[
-                        sys_cons.BOOT_SOURCE_TARGET_USB_CD]
-                    in self.boot.allowed_values):
-                fishy_target = sys_maps.BOOT_SOURCE_TARGET_MAP_REV[
-                    sys_cons.BOOT_SOURCE_TARGET_USB_CD]
-                LOG.debug('Boot from vMedia was requested on a SuperMicro'
-                          'machine. Overriding boot device from %s to %s.',
-                          sys_cons.BOOT_SOURCE_TARGET_CD,
-                          fishy_target)
 
             data['Boot']['BootSourceOverrideTarget'] = fishy_target
 
@@ -284,23 +262,9 @@ class System(base.ResourceBase):
 
             data['Boot']['BootSourceOverrideMode'] = fishy_mode
 
-        headers = None
-        etag = self._get_etag()
-        path = self.path
-
-        # NOTE(janders): checking if @Redfish.Settings are available; if so
-        # using the URI from the SettingsObject. Also ensuring the ETag URI
-        # matches in this case (the one above would not be valid for new URI).
-        if self._settings and self._settings.resource_uri:
-            path = self._settings.resource_uri
-            resp = self._conn.get(path)
-            etag = resp.headers.get('ETag')
-
         # TODO(lucasagomes): Check the return code and response body ?
         #                    Probably we should call refresh() as well.
-        if etag is not None:
-            headers = {'If-Match': etag}
-        self._conn.patch(path, data=data, headers=headers)
+        self._conn.patch(self.path, data=data)
 
     # TODO(etingof): we should remove this method, eventually
     def set_system_boot_source(
@@ -362,7 +326,7 @@ class System(base.ResourceBase):
         return processor.ProcessorCollection(
             self._conn, self._get_processor_collection_path(),
             redfish_version=self.redfish_version,
-            registries=self.registries)
+            registries=self.registries, root=self.root)
 
     @property
     @utils.cache_it
@@ -377,7 +341,7 @@ class System(base.ResourceBase):
             self._conn,
             utils.get_sub_resource_path_by(self, "EthernetInterfaces"),
             redfish_version=self.redfish_version,
-            registries=self.registries)
+            registries=self.registries, root=self.root)
 
     @property
     @utils.cache_it
@@ -392,7 +356,7 @@ class System(base.ResourceBase):
             self._conn,
             utils.get_sub_resource_path_by(self, 'Bios'),
             redfish_version=self.redfish_version,
-            registries=self.registries)
+            registries=self.registries, root=self.root)
 
     @property
     @utils.cache_it
@@ -414,7 +378,7 @@ class System(base.ResourceBase):
         return sys_simple_storage.SimpleStorageCollection(
             self._conn, utils.get_sub_resource_path_by(self, "SimpleStorage"),
             redfish_version=self.redfish_version,
-            registries=self.registries)
+            registries=self.registries, root=self.root)
 
     @property
     @utils.cache_it
@@ -437,7 +401,7 @@ class System(base.ResourceBase):
         return sys_storage.StorageCollection(
             self._conn, utils.get_sub_resource_path_by(self, "Storage"),
             redfish_version=self.redfish_version,
-            registries=self.registries)
+            registries=self.registries, root=self.root)
 
     @property
     @utils.cache_it
@@ -455,7 +419,7 @@ class System(base.ResourceBase):
 
         return [manager.Manager(self._conn, path,
                                 redfish_version=self.redfish_version,
-                                registries=self.registries)
+                                registries=self.registries, root=self.root)
                 for path in paths]
 
     @property
@@ -474,7 +438,7 @@ class System(base.ResourceBase):
 
         return [chassis.Chassis(self._conn, path,
                                 redfish_version=self.redfish_version,
-                                registries=self.registries)
+                                registries=self.registries, root=self.root)
                 for path in paths]
 
     @property
@@ -490,7 +454,7 @@ class System(base.ResourceBase):
             self._conn,
             utils.get_sub_resource_path_by(self, 'SecureBoot'),
             redfish_version=self.redfish_version,
-            registries=self.registries)
+            registries=self.registries, root=self.root)
 
 
 class SystemCollection(base.ResourceCollectionBase):
@@ -499,7 +463,8 @@ class SystemCollection(base.ResourceCollectionBase):
     def _resource_type(self):
         return System
 
-    def __init__(self, connector, path, redfish_version=None, registries=None):
+    def __init__(self, connector, path, redfish_version=None, registries=None,
+                 root=None):
         """A class representing a ComputerSystemCollection
 
         :param connector: A Connector instance
@@ -508,6 +473,8 @@ class SystemCollection(base.ResourceCollectionBase):
             the object according to schema of the given version.
         :param registries: Dict of Redfish Message Registry objects to be
             used in any resource that needs registries to parse messages
+        :param root: Sushy root object. Empty for Sushy root itself.
         """
         super(SystemCollection, self).__init__(
-            connector, path, redfish_version, registries)
+            connector, path, redfish_version=redfish_version,
+            registries=registries, root=root)
